@@ -6,6 +6,7 @@
 #' @param y_test A vector of holdout/validation data or the name in object (if fit object provided but alternative variable name required).
 #' @param predictions A vector predictions or the name in object (if fit object provided but alternative variable name required).
 #' @param return_xtab Logical. If TRUE, returns confusion matrix, which is a crosstable with correct predictions on the diagonal (if all levels are predicted at least once). If FALSE, returns (rectangular) table with columns for percent correct, most common misclassification, second most common misclassification, and other predictions. Defaults to TRUE (crosstable-style) only if number of levels < 6.
+#' @param digits Number of digits for proportions when return_xtab=FALSE; if NULL, no rounding is performed.
 #' @return confusion matrix or table as specified by return_xtab.
 #' #' @examples
 #' mtcars$make <- unlist(lapply(strsplit(rownames(mtcars), " "), function(tokens) tokens[1]))
@@ -13,7 +14,7 @@
 #' confusion(company)     # same as above confusion$company if is_keras_available() == TRUE
 #' confusion(company, return_xtab = FALSE) # focus on pCorrect, most common errors
 #' @export
-confusion <- function(object = NULL, y_test = NULL, predictions = NULL, return_xtab = NULL){
+confusion <- function(object = NULL, y_test = NULL, predictions = NULL, return_xtab = NULL, digits=3){
   
   obj <- data.frame(y_test = if(is.null(object)) y_test else object[[if(is.null(y_test)) "y_test" else y_test]],
                     predictions = if(is.null(object)) predictions else object[[if(is.null(predictions)) "predictions" else predictions]],
@@ -31,7 +32,8 @@ confusion <- function(object = NULL, y_test = NULL, predictions = NULL, return_x
     obj[["correct"]] <- obj$y_test == obj$predictions
     cf <- data.frame(label = unique(obj$y_test)) 
     # confusion 
-
+    
+    cf[["N"]] <- NA
     cf[["pCorrect"]] <- NA
     cf[["MCE"]] <- NA # Most Common Error
     cf[["pMCE"]] <- 0 # proportion that are MCE
@@ -42,7 +44,7 @@ confusion <- function(object = NULL, y_test = NULL, predictions = NULL, return_x
     for(i in 1:nrow(cf)){
       
       lab_i <- obj$y_test == cf$label[i]
-      Nlab_i <- sum(lab_i)
+      cf$N[i] <- Nlab_i <- sum(lab_i)
       
       cf$pCorrect[i] <- mean(obj$y_test[lab_i] == obj$predictions[lab_i])
       
@@ -65,6 +67,13 @@ confusion <- function(object = NULL, y_test = NULL, predictions = NULL, return_x
       }
             
     }
+    
+    if(!is.null(digits)){
+      cf$pCorrect <- round(cf$pCorrect, digits=digits) 
+      cf$pMCE <-  round(cf$pMCE, digits=digits)
+      cf$pMCE2 <- round(cf$pMCE2, digits=digits) 
+      cf$pOther <- round(cf$pOther, digits=digits)
+    }
    return(cf) 
   }
     
